@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2012 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -210,6 +210,103 @@
                     rules  => [ augeas => { level => 'normal', } ],
                 }
             },
+
+            'store_class_in_hash' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'hidden',
+                description => 'Specify element hash name that will contain all INI classes. '
+                    .'See L<Config::Model::Backend::IniFile/"Arbitrary class name">',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+
+            'section_map' => {
+                type       => 'hash',
+                level      => 'hidden',
+                index_type => 'string',
+                description => 'Specify element name that will contain one INI class. E.g. to store '
+                     .'INI class [foo] in element Foo, specify { foo => "Foo" } ',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                },
+                cargo => { 
+                    type => 'leaf',
+                    value_type => 'uniline',
+                },
+            },
+
+            'split_list_value' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'hidden',
+                description => 'Regexp to split values stored in list element. Usually "\s+" or "[,\s]"',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+
+            'join_list_value' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'hidden',
+                description => 'string to join values from list element. Usually " " or ", "',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+
+            'write_boolean_as' => {
+                type       => 'list',
+                description => 'Specify how to write a boolean value in config file. Suggested values are '
+                    . '"no","yes". ',
+                max_index => 1,
+                cargo => { 
+                    type => 'leaf',
+                    value_type => 'uniline',
+                },
+            },
+
+            force_lc_section => {
+                type => 'leaf',
+                value_type => 'boolean',
+                level      => 'hidden',
+                upstream_default => 0,
+                description => "force section to be lowercase",
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+            force_lc_key => {
+                type => 'leaf',
+                value_type => 'boolean',
+                level      => 'hidden',
+                upstream_default => 0,
+                description => "force key names to be lowercase",
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+            force_lc_value => {
+                type => 'leaf',
+                value_type => 'boolean',
+                level      => 'hidden',
+                upstream_default => 0,
+                description => "force values to be lowercase",
+                warp => {
+                    follow => '- backend',
+                    rules  => [ ini_file => { level => 'normal', } ],
+                }
+            },
+
+
             'config_file' => {
                 type       => 'leaf',
                 value_type => 'uniline',
@@ -218,6 +315,7 @@
                 description =>
 'Specify the configuration file (without path) that will store configuration information',
             },
+
              'full_dump' => {
                 type             => 'leaf',
                 value_type       => 'boolean',
@@ -229,6 +327,7 @@
                     rules  => [ '$backend =~ /yaml|perl/i' => { level => 'normal', } ],
                 }
             },
+
            'comment_delimiter' => {
                 type             => 'leaf',
                 value_type       => 'uniline',
@@ -294,7 +393,6 @@
                 type         => 'leaf',
                 value_type   => 'uniline',
                 level        => 'normal',
-                mandatory    => 1,
                 migrate_from => {
                     formula   => '$old',
                     variables => { old => '- - read_config_dir' },
